@@ -1,20 +1,20 @@
 #pragma once
 #include <QLatin1String>
 
-#define KWIN_PLUGIN_VERSION_STRING "6.5.5"
-#define PROJECT_VERSION_PATCH 5
+#define KWIN_PLUGIN_VERSION_STRING "6.5.90"
+#define PROJECT_VERSION_PATCH 90
 
 #define KWIN_BUILD_DECORATIONS 1
 #define KWIN_BUILD_KCMS 1
 #define KWIN_BUILD_NOTIFICATIONS 1
-#define KWIN_BUILD_SCREENLOCKER 0
+#define KWIN_BUILD_SCREENLOCKER 1
 #define KWIN_BUILD_TABBOX 1
 #define KWIN_BUILD_ACTIVITIES 1
 #define KWIN_BUILD_GLOBALSHORTCUTS 1
 #define KWIN_BUILD_X11 1
 #define KWIN_BUILD_QACCESSIBILITYCLIENT 0
 constexpr QLatin1String KWIN_CONFIG("kwinrc");
-constexpr QLatin1String KWIN_VERSION_STRING("6.5.5");
+constexpr QLatin1String KWIN_VERSION_STRING("6.5.90");
 constexpr QLatin1String XCB_VERSION_STRING("1.17.0");
 constexpr QLatin1String KWIN_KILLER_BIN("/usr/libexec/kwin_killer_helper");
 constexpr QLatin1String LIBEXEC_DIR("/usr/libexec");
@@ -30,5 +30,4 @@ constexpr QLatin1String LIBEXEC_DIR("/usr/libexec");
 #define HAVE_LIBDRM_FAUX 1
 
 constexpr QLatin1String XWAYLAND_SESSION_SCRIPTS("/etc/xdg/Xwayland-session.d");
-
-#define HAVE_LIBINPUT_INPUT_AREA 1
+#define HAVE_WAYLAND_PROTOCOLS_147 1
